@@ -11,18 +11,22 @@
 (custom-add-loads 'compile-python '("mode-compile"))
 (custom-add-loads 'compile-c++ '("mode-compile"))
 (custom-add-loads 'compile-ada '("mode-compile"))
-(custom-add-loads 'languages '("asm-mode" "cperl-mode" "f90" "fortran" "icon" "javascript-mode" "mode-compile" "modula2" "pascal" "php-mode" "prolog" "python-mode" "rexx-mode" "ruby-mode" "simula" "tcl" "verilog-mode" "vrml-mode"))
+(custom-add-loads 'languages '("asm-mode" "cperl-mode" "f90" "fortran" "icon" "javascript-mode" "mode-compile" "modula2" "pascal" "php-mode" "prolog" "python-mode" "rexx-mode" "rpm-spec-mode" "ruby-mode" "simula" "tcl" "verilog-mode" "vrml-mode"))
 (custom-add-loads 'asm '("asm-mode"))
 (custom-add-loads 'cperl-autoinsert-details '("cperl-mode"))
 (custom-add-loads 'diff '("diff-mode"))
 (custom-add-loads 'fortran-indent '("fortran"))
+(custom-add-loads 'rpm-spec '("rpm-spec-mode"))
 (custom-add-loads 'processes '("sql"))
 (custom-add-loads 'cperl-help-system '("cperl-mode"))
 (custom-add-loads 'compile-fortran '("mode-compile"))
 (custom-add-loads 'compilation-script '("mode-compile"))
 (custom-add-loads 'php '("php-mode"))
 (custom-add-loads 'development '("mode-compile"))
+(custom-add-loads 'oop '("eiffel"))
 (custom-add-loads 'javascript-shell '("javascript-mode"))
+(custom-add-loads 'rpm-spec-faces '("rpm-spec-mode"))
+(custom-add-loads 'eiffel '("eiffel"))
 (custom-add-loads 'verilog-mode '("verilog-mode"))
 (custom-add-loads 'ruby-inferior-mode '("inf-ruby"))
 (custom-add-loads 'cperl '("cperl-mode"))
@@ -45,6 +49,7 @@
 (custom-add-loads 'cperl-affected-by-hairy '("cperl-mode"))
 (custom-add-loads 'cperl-indentation-details '("cperl-mode"))
 (custom-add-loads 'f90-indent '("f90"))
+(custom-add-loads 'eiffel-compile '("eiffel"))
 (custom-add-loads 'verilog-mode-actions '("verilog-mode"))
 (custom-add-loads 'compile-sh '("mode-compile"))
 (custom-add-loads 'compilation-frame '("mode-compile"))
@@ -53,6 +58,7 @@
 (custom-add-loads 'p4 '("p4"))
 (custom-add-loads 'python '("python-mode"))
 (custom-add-loads 'cperl-faces '("cperl-mode"))
+(custom-add-loads 'eiffel-indent '("eiffel"))
 (custom-add-loads 'verilog-mode-indent '("verilog-mode"))
 (custom-add-loads 'compilation-remote '("mode-compile"))
 (custom-add-loads 'compile-perl '("mode-compile"))
@@ -61,7 +67,7 @@
 (custom-add-loads 'rexx '("rexx-mode"))
 (custom-add-loads 'compile-csh '("mode-compile"))
 (custom-add-loads 'f90 '("f90"))
-(custom-add-loads 'faces '("make-mode"))
+(custom-add-loads 'faces '("make-mode" "rpm-spec-mode"))
 (custom-add-loads 'font-lock-highlighting-faces '("verilog-mode"))
 (custom-add-loads 'tools '("diff-mode" "make-mode" "mode-compile" "p4"))
 (custom-add-loads 'compile-tcl '("mode-compile"))
